pub struct CheckpointTransaction {
pub transaction: Transaction,
pub effects: TransactionEffects,
pub events: Option<TransactionEvents>,
pub input_objects: Vec<Object>,
pub output_objects: Vec<Object>,
}Fields
transaction: TransactionThe input Transaction
effects: TransactionEffectsThe effects produced by executing this transaction
events: Option<TransactionEvents>The events, if any, emitted by this transactions during execution
input_objects: Vec<Object>The state of all inputs to this transaction as they were prior to execution.
output_objects: Vec<Object>The state of all output objects created or mutated or unwrapped by this transaction.
Implementations
Sourceimpl CheckpointTransaction
impl CheckpointTransaction
pub fn removed_objects_pre_version(&self) -> impl Iterator<Item = &Object>
pub fn removed_object_refs_post_version( &self, ) -> impl Iterator<Item = ObjectRef>
pub fn changed_objects( &self, ) -> impl Iterator<Item = (&Object, Option<&Object>)>
pub fn created_objects(&self) -> impl Iterator<Item = &Object>
pub fn execution_data(&self) -> ExecutionData